@@ -45,7 +45,7 @@ public:
     Plugin_JAlbumExport(QObject* const parent, const QVariantList& args);
     virtual ~Plugin_JAlbumExport();
 
-    void setup(QWidget* const) Q_DECL_OVERRIDE;
+    void setup(QWidget* const) override;
 
 private Q_SLOTS:
 
